.. _bwcompat_module:

:mod:`cubicweb_web.bwcompat`
----------------------------

.. automodule:: cubicweb_web.bwcompat

    .. autofunction:: includeme

    .. autoclass:: PyramidSessionHandler
        :members:

    .. autoclass:: CubicWebPyramidHandler
        :members:

        .. automethod:: __call__

    .. autoclass:: TweenHandler
        :members:
